# OpenDR Speech Recognition - MatchboxNet

This folder contains the OpenDR learner for MatchboxNet.

## Sources

The algorithm files were written from scratch based on the paper [MatchboxNet: 1D Time-Channel Separable Convolutional Neural Network Architecture for Speech Commands Recognition](https://arxiv.org/abs/2004.08531).
